@@ -398,9 +398,9 @@ class Connection(QTcpSocket):
                 participantsList = msg.split(SeparatorToken)
             self.participants.emit(participantsList[:])
         elif self.__currentDataType == Connection.Editor:
-            hash, fn, msg = \
+            hashStr, fn, msg = \
                 str(self.__buffer, encoding="utf-8").split(SeparatorToken)
-            self.editorCommand.emit(hash, fn, msg)
+            self.editorCommand.emit(hashStr, fn, msg)
         
         self.__currentDataType = Connection.Undefined
         self.__numBytesForCurrentDataType = 0
