@@ -693,15 +693,15 @@ class DebugServer(QTcpServer):
             self.__addWatchPoints(
                 QModelIndex(), startIndex.row(), endIndex.row())
         
-    def getClientCapabilities(self, type):
+    def getClientCapabilities(self, clientType):
         """
         Public method to retrieve the debug clients capabilities.
         
-        @param type debug client type (string)
+        @param clientType debug client type (string)
         @return debug client capabilities (integer)
         """
         try:
-            return self.__debuggerInterfaceRegistry[type][0]
+            return self.__debuggerInterfaceRegistry[clientType][0]
         except KeyError:
             return 0    # no capabilities
         
@@ -996,17 +996,27 @@ class DebugServer(QTcpServer):
         """
         self.debuggerInterface.remoteContinue(special)
 
-    def remoteBreakpoint(self, fn, line, set, cond=None, temp=False):
+    def remoteMoveIP(self, line):
+        """
+        Public method to move the instruction pointer to a different line.
+        
+        @param line the new line, where execution should be continued
+        """
+        self.debuggerInterface.remoteMoveIP(line)
+
+    def remoteBreakpoint(self, fn, line, setBreakpoint, cond=None, temp=False):
         """
         Public method to set or clear a breakpoint.
         
         @param fn filename the breakpoint belongs to (string)
         @param line linenumber of the breakpoint (int)
-        @param set flag indicating setting or resetting a breakpoint (boolean)
+        @param setBreakpoint flag indicating setting or resetting a breakpoint
+            (boolean)
         @param cond condition of the breakpoint (string)
         @param temp flag indicating a temporary breakpoint (boolean)
         """
-        self.debuggerInterface.remoteBreakpoint(fn, line, set, cond, temp)
+        self.debuggerInterface.remoteBreakpoint(fn, line, setBreakpoint, cond,
+                                                temp)
         
     def __remoteBreakpointEnable(self, fn, line, enable):
         """
@@ -1029,17 +1039,17 @@ class DebugServer(QTcpServer):
         """
         self.debuggerInterface.remoteBreakpointIgnore(fn, line, count)
         
-    def __remoteWatchpoint(self, cond, set, temp=False):
+    def __remoteWatchpoint(self, cond, setWatch, temp=False):
         """
         Private method to set or clear a watch expression.
         
         @param cond expression of the watch expression (string)
-        @param set flag indicating setting or resetting a watch expression
+        @param setWatch flag indicating setting or resetting a watch expression
             (boolean)
         @param temp flag indicating a temporary watch expression (boolean)
         """
         # cond is combination of cond and special (s. watch expression viewer)
-        self.debuggerInterface.remoteWatchpoint(cond, set, temp)
+        self.debuggerInterface.remoteWatchpoint(cond, setWatch, temp)
     
     def __remoteWatchpointEnable(self, cond, enable):
         """
@@ -1086,36 +1096,38 @@ class DebugServer(QTcpServer):
         """
         self.debuggerInterface.remoteSetThread(tid)
         
-    def remoteClientVariables(self, scope, filter, framenr=0):
+    def remoteClientVariables(self, scope, filterList, framenr=0):
         """
         Public method to request the variables of the debugged program.
         
         @param scope the scope of the variables (0 = local, 1 = global)
-        @param filter list of variable types to filter out (list of int)
+        @param filterList list of variable types to filter out (list of int)
         @param framenr framenumber of the variables to retrieve (int)
         """
-        self.debuggerInterface.remoteClientVariables(scope, filter, framenr)
+        self.debuggerInterface.remoteClientVariables(scope, filterList,
+                                                     framenr)
         
-    def remoteClientVariable(self, scope, filter, var, framenr=0):
+    def remoteClientVariable(self, scope, filterList, var, framenr=0):
         """
         Public method to request the variables of the debugged program.
         
         @param scope the scope of the variables (0 = local, 1 = global)
-        @param filter list of variable types to filter out (list of int)
+        @param filterList list of variable types to filter out (list of int)
         @param var list encoded name of variable to retrieve (string)
         @param framenr framenumber of the variables to retrieve (int)
         """
         self.debuggerInterface.remoteClientVariable(
-            scope, filter, var, framenr)
+            scope, filterList, var, framenr)
         
-    def remoteClientSetFilter(self, scope, filter):
+    def remoteClientSetFilter(self, scope, filterStr):
         """
         Public method to set a variables filter list.
         
         @param scope the scope of the variables (0 = local, 1 = global)
-        @param filter regexp string for variable names to filter out (string)
+        @param filterStr regexp string for variable names to filter out
+            (string)
         """
-        self.debuggerInterface.remoteClientSetFilter(scope, filter)
+        self.debuggerInterface.remoteClientSetFilter(scope, filterStr)
         
     def setCallTraceEnabled(self, on):
         """
@@ -1447,54 +1459,54 @@ class DebugServer(QTcpServer):
         """
         self.utStopTest.emit()
         
-    def clientUtTestFailed(self, testname, traceback, id):
+    def clientUtTestFailed(self, testname, traceback, testId):
         """
         Public method to process the client test failed info.
         
         @param testname name of the test (string)
         @param traceback lines of traceback info (list of strings)
-        @param id id of the test (string)
+        @param testId id of the test (string)
         """
-        self.utTestFailed.emit(testname, traceback, id)
+        self.utTestFailed.emit(testname, traceback, testId)
         
-    def clientUtTestErrored(self, testname, traceback, id):
+    def clientUtTestErrored(self, testname, traceback, testId):
         """
         Public method to process the client test errored info.
         
         @param testname name of the test (string)
         @param traceback lines of traceback info (list of strings)
-        @param id id of the test (string)
+        @param testId id of the test (string)
         """
-        self.utTestErrored.emit(testname, traceback, id)
+        self.utTestErrored.emit(testname, traceback, testId)
         
-    def clientUtTestSkipped(self, testname, reason, id):
+    def clientUtTestSkipped(self, testname, reason, testId):
         """
         Public method to process the client test skipped info.
         
         @param testname name of the test (string)
         @param reason reason for skipping the test (string)
-        @param id id of the test (string)
+        @param testId id of the test (string)
         """
-        self.utTestSkipped.emit(testname, reason, id)
+        self.utTestSkipped.emit(testname, reason, testId)
         
-    def clientUtTestFailedExpected(self, testname, traceback, id):
+    def clientUtTestFailedExpected(self, testname, traceback, testId):
         """
         Public method to process the client test failed expected info.
         
         @param testname name of the test (string)
         @param traceback lines of traceback info (list of strings)
-        @param id id of the test (string)
+        @param testId id of the test (string)
         """
-        self.utTestFailedExpected.emit(testname, traceback, id)
+        self.utTestFailedExpected.emit(testname, traceback, testId)
         
-    def clientUtTestSucceededUnexpected(self, testname, id):
+    def clientUtTestSucceededUnexpected(self, testname, testId):
         """
         Public method to process the client test succeeded unexpected info.
         
         @param testname name of the test (string)
-        @param id id of the test (string)
+        @param testId id of the test (string)
         """
-        self.utTestSucceededUnexpected.emit(testname, id)
+        self.utTestSucceededUnexpected.emit(testname, testId)
         
     def clientUtFinished(self):
         """
