@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -653,11 +653,13 @@ class E5SideBar(QWidget):
         @param old reference to the widget, that lost focus (QWidget or None)
         @param now reference to the widget having the focus (QWidget or None)
         """
-        self.__hasFocus = self.isAncestorOf(now)
-        if self.__autoHide and not self.__hasFocus and not self.isMinimized():
-            self.shrink()
-        elif self.__autoHide and self.__hasFocus and self.isMinimized():
-            self.expand()
+        if isinstance(now, QWidget):
+            self.__hasFocus = self.isAncestorOf(now)
+            if self.__autoHide and not self.__hasFocus and \
+                    not self.isMinimized():
+                self.shrink()
+            elif self.__autoHide and self.__hasFocus and self.isMinimized():
+                self.expand()
     
     def enterEvent(self, event):
         """
