@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -213,8 +213,8 @@ class DownloadItem(QWidget, Ui_DownloadItem):
             self.__autoOpen = dlg.getAction() == "open"
             if PYQT_VERSION_STR >= "5.0.0":
                 from PyQt5.QtCore import QStandardPaths
-                tempLocation = QStandardPaths.storageLocation(
-                    QStandardPaths.TempLocation)
+                tempLocation = QStandardPaths.standardLocations(
+                    QStandardPaths.TempLocation)[0]
             else:
                 from PyQt5.QtGui import QDesktopServices
                 tempLocation = QDesktopServices.storageLocation(
@@ -560,8 +560,8 @@ class DownloadItem(QWidget, Ui_DownloadItem):
             info = self.tr("{0} of {1} ({2}/sec)\n{3}")\
                 .format(
                     dataString(self.__bytesReceived),
-                    bytesTotal == -1 and self.tr("?")
-                    or dataString(bytesTotal),
+                    bytesTotal == -1 and self.tr("?") or
+                    dataString(bytesTotal),
                     dataString(int(speed)),
                     remaining)
         else:
