@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 
@@ -10,10 +10,12 @@ Module implementing the helpbrowser using QWebView.
 
 from __future__ import unicode_literals
 try:
-    str = unicode
+    str = unicode       # __IGNORE_EXCEPTION__
 except NameError:
     pass
 
+import os
+
 from PyQt5.QtCore import pyqtSlot, pyqtSignal, QObject, QT_TRANSLATE_NOOP, \
     QUrl, QBuffer, QIODevice, QFileInfo, Qt, QTimer, QEvent, \
     QRect, QFile, QPoint, QByteArray, qVersion
@@ -38,6 +40,7 @@ import Helpviewer
 import Preferences
 import UI.PixmapCache
 import Globals
+import Utilities
 
 try:
     from PyQt5.QtNetwork import QSslCertificate
@@ -686,7 +689,8 @@ class HelpWebPage(QWebPage):
             return
         
         if 'zoom' in data:
-            frame.page().view().setZoomValue(int(data['zoom'] * 100))
+            frame.page().view().setZoomValue(int(data['zoom'] * 100),
+                                             saveValue=False)
         
         if 'scrollPos' in data and frame.scrollPosition() == QPoint(0, 0):
             frame.setScrollPosition(data['scrollPos'])
@@ -900,7 +904,14 @@ class HelpBrowser(QWebView):
             return
         
         if not name.scheme():
-            name.setUrl(Preferences.getHelp("DefaultScheme") + name.toString())
+            if not os.path.exists(name.toString()):
+                name.setScheme(Preferences.getWebBrowser("DefaultScheme"))
+            else:
+                if Utilities.isWindowsPlatform():
+                    name.setUrl("file:///" + Utilities.fromNativeSeparators(
+                        name.toString()))
+                else:
+                    name.setUrl("file://" + name.toString())
         
         if len(name.scheme()) == 1 or \
            name.scheme() == "file":
@@ -1056,11 +1067,14 @@ class HelpBrowser(QWebView):
         """
         self.setZoomValue(self.__currentZoom)
     
-    def setZoomValue(self, value):
+    def setZoomValue(self, value, saveValue=True):
         """
         Public method to set the zoom value.
         
         @param value zoom value (integer)
+        @keyparam saveValue flag indicating to save the zoom value with the
+            zoom manager
+        @type bool
         """
         if value != self.zoomValue():
             try:
@@ -1068,6 +1082,9 @@ class HelpBrowser(QWebView):
             except AttributeError:
                 self.setTextSizeMultiplier(value / 100.0)
             self.__currentZoom = value
+            if saveValue:
+                Helpviewer.HelpWindow.HelpWindow.zoomManager().setZoomValue(
+                    self.url(), value)
             self.zoomValueChanged.emit(value)
     
     def zoomValue(self):
@@ -1164,6 +1181,31 @@ class HelpBrowser(QWebView):
         from .UserAgent.UserAgentMenu import UserAgentMenu
         menu = QMenu(self)
         
+        if self.url().toString() == "eric:speeddial":
+            # special menu for the spedd dial page
+            menu.addAction(self.mw.newTabAct)
+            menu.addAction(self.mw.newAct)
+            menu.addSeparator()
+            menu.addAction(self.mw.backAct)
+            menu.addAction(self.mw.forwardAct)
+            menu.addSeparator()
+            menu.addAction(
+                UI.PixmapCache.getIcon("plus.png"),
+                self.tr("Add New Page"), self.__addSpeedDial)
+            menu.addAction(
+                UI.PixmapCache.getIcon("preferences-general.png"),
+                self.tr("Configure Speed Dial"), self.__configureSpeedDial)
+            menu.addSeparator()
+            menu.addAction(
+                UI.PixmapCache.getIcon("reload.png"),
+                self.tr("Reload All Dials"), self.__reloadAllSpeedDials)
+            menu.addSeparator()
+            menu.addAction(
+                self.tr("Reset to Default Dials"), self.__resetSpeedDials)
+            
+            menu.exec_(evt.globalPos())
+            return
+        
         frameAtPos = self.page().frameAt(evt.pos())
         hit = self.page().mainFrame().hitTestContent(evt.pos())
         if not hit.linkUrl().isEmpty():
@@ -1610,8 +1652,8 @@ class HelpBrowser(QWebView):
         
         searchUrl = QUrl(self.page().mainFrame().baseUrl().resolved(
             QUrl(formElement.attribute("action"))))
-        if searchUrl.scheme() != "http":
-            return
+##        if searchUrl.scheme() != "http":
+##            return
         
         if qVersion() >= "5.0.0":
             from PyQt5.QtCore import QUrlQuery
@@ -1923,9 +1965,9 @@ class HelpBrowser(QWebView):
         pinch = evt.gesture(Qt.PinchGesture)
         if pinch:
             if pinch.state() == Qt.GestureStarted:
-                pinch.setScaleFactor(self.__currentZoom / 100.0)
-            else:
-                scaleFactor = pinch.scaleFactor()
+                pinch.setTotalScaleFactor(self.__currentZoom / 100.0)
+            elif pinch.state() == Qt.GestureUpdated:
+                scaleFactor = pinch.totalScaleFactor()
                 self.__currentZoom = int(scaleFactor * 100)
                 self.__applyZoom()
             evt.accept()
@@ -2003,6 +2045,10 @@ class HelpBrowser(QWebView):
             self.zoomIn()
             self.zoomOut()
         
+        zoomValue = Helpviewer.HelpWindow.HelpWindow.zoomManager()\
+            .zoomValue(self.url())
+        self.setZoomValue(zoomValue)
+        
         if ok:
             self.mw.adBlockManager().page().hideBlockedPageEntries(self.page())
             self.mw.passwordManager().fill(self.page())
@@ -2591,6 +2637,34 @@ class HelpBrowser(QWebView):
         editor.setText(src, "Html")
         editor.setLanguage("dummy.html")
         editor.show()
+    
+    ###########################################################################
+    ## Speed Dial slots below
+    ###########################################################################
+    
+    def __addSpeedDial(self):
+        """
+        Private slot to add a new speed dial.
+        """
+        self.page().mainFrame().evaluateJavaScript("addSpeedDial();")
+    
+    def __configureSpeedDial(self):
+        """
+        Private slot to configure the speed dial.
+        """
+        self.page().mainFrame().evaluateJavaScript("configureSpeedDial();")
+    
+    def __reloadAllSpeedDials(self):
+        """
+        Private slot to reload all speed dials.
+        """
+        self.page().mainFrame().evaluateJavaScript("reloadAll();")
+    
+    def __resetSpeedDials(self):
+        """
+        Private slot to reset all speed dials to the default pages.
+        """
+        self.__speedDial.resetDials()
 
 
 def contentSniff(data):
