@@ -1034,7 +1034,7 @@ class PluginManager(QObject):
             pluginName in self.__onDemandActiveModules
     
     ###########################################################################
-    ## Specialized plugin module handling methods below
+    ## Specialized plug-in module handling methods below
     ###########################################################################
     
     ###########################################################################
@@ -1277,12 +1277,12 @@ class PluginManager(QObject):
                 return
             
             # 3. Check the version of the archive file
-            zip = zipfile.ZipFile(archive, "r")
+            zipFile = zipfile.ZipFile(archive, "r")
             try:
-                aversion = zip.read("VERSION").decode("utf-8")
+                aversion = zipFile.read("VERSION").decode("utf-8")
             except KeyError:
                 aversion = ""
-            zip.close()
+            zipFile.close()
             
             if aversion != version:
                 self.__updateAvailable = True
@@ -1297,6 +1297,30 @@ class PluginManager(QObject):
         ignored = self.__sslErrorHandler.sslErrorsReply(reply, errors)[0]
         if ignored == E5SslErrorHandler.NotIgnored:
             self.__downloadCancelled = True
+    
+    ########################################################################
+    ## Methods to clear private data of plug-ins below
+    ########################################################################
+    
+    def clearPluginsPrivateData(self, type_):
+        """
+        Public method to clear the private data of plug-ins of a specified
+        type.
+        
+        Plugins supporting this functionality must support the module function
+        clearPrivateData() and have the module level attribute pluginType.
+        
+        @param type_ type of the plugin to be activated (string)
+        """
+        for name, module in \
+            list(self.__onDemandActiveModules.items()) + \
+            list(self.__onDemandInactiveModules.items()) + \
+            list(self.__activeModules.items()) + \
+                list(self.__inactiveModules.items()):
+            if getattr(module, "pluginType", "") == type_:
+                if hasattr(module, "clearPrivateData"):
+                    module.clearPrivateData()
+        # TODO: document this in the plug-ins paper
 
 #
 # eflag: noqa = M801
