@@ -419,11 +419,16 @@ _messages = {
         "NamingStyleChecker",
         "names 'l', 'O' and 'I' should be avoided"),
 
-    # McCabe messages
+    # Code complexity messages
     "C101": QCoreApplication.translate(
-        "McCabeChecker", "'{0}' is too complex ({1})"),
+        "ComplexityChecker", "'{0}' is too complex ({1})"),
+    "C111": QCoreApplication.translate(
+        "ComplexityChecker", "source code line is too complex ({0})"),
+    "C112": QCoreApplication.translate(
+        "ComplexityChecker",
+        "overall source code line complexity is too high ({0})"),
     "C901": QCoreApplication.translate(
-        "McCabeChecker", "{0}: {1}"),
+        "ComplexityChecker", "{0}: {1}"),
     
     # Messages of the Miscellaneous Checker
     "M101": QCoreApplication.translate(
@@ -438,9 +443,38 @@ _messages = {
     "M112": QCoreApplication.translate(
         "MiscellaneousChecker",
         "copyright notice contains invalid author"),
-    "M121": QCoreApplication.translate(
+    "M131": QCoreApplication.translate(
         "MiscellaneousChecker",
-        "blind except: statement"),         # __IGNORE_WARNING__
+        '"{0}" is a Python builtin and is being shadowed; '
+        'consider renaming the variable'),
+    "M132": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        '"{0}" is used as an argument and thus shadows a '
+        'Python builtin; consider renaming the argument'),
+    "M191": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        'unnecessary generator - rewrite as a list comprehension'),
+    "M192": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        'unnecessary generator - rewrite as a set comprehension'),
+    "M193": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        'unnecessary generator - rewrite as a dict comprehension'),
+    "M194": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        'unnecessary list comprehension - rewrite as a set comprehension'),
+    "M195": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        'unnecessary list comprehension - rewrite as a dict comprehension'),
+    "M196": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        'unnecessary list literal - rewrite as a set literal'),
+    "M197": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        'unnecessary list literal - rewrite as a dict literal'),
+    "M198": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        'unnecessary list comprehension - "{0}" can take a generator'),
     "M601": QCoreApplication.translate(
         "MiscellaneousChecker",
         "found {0} formatter"),
@@ -486,6 +520,12 @@ _messages = {
     "M811": QCoreApplication.translate(
         "MiscellaneousChecker",
         "one element tuple found"),
+    "M821": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "mutable default argument of type {0}"),
+    "M822": QCoreApplication.translate(
+        "MiscellaneousChecker",
+        "mutable default argument of type {0}"),
     "M901": QCoreApplication.translate(
         "MiscellaneousChecker",
         "{0}: {1}"),
@@ -665,15 +705,22 @@ _messages_sample_args = {
     "D232": ["public"],
     "D901": ["SyntaxError", "Invalid Syntax"],
     "C101": ["foo.bar", "42"],
+    "C111": [42],
+    "C112": [12.0],
     "C901": ["SyntaxError", "Invalid Syntax"],
     "M102": ["enc42"],
-    "M131": ["%s"],
+    "M131": ["list"],
+    "M132": ["list"],
+    "M198": ["sorted"],
+    "M601": ["%s"],
     "M621": [5],
     "M622": ["foo"],
     "M631": [5],
     "M632": ["foo"],
     "M701": ["print_function, unicode_literals", "print_function"],
     "M702": ["print_function, unicode_literals"],
+    "M821": ["Dict"],
+    "M822": ["Call"],
     "M901": ["SyntaxError", "Invalid Syntax"],
     "FWRITE_ERROR": ["IOError"],
 }
