@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -84,8 +84,12 @@ class EditorHighlightingStylesPage(ConfigurationPageBase,
         self.lexers = lexers
         
         # set initial values
+        import QScintilla.Lexers
         languages = sorted([''] + list(self.lexers.keys()))
-        self.lexerLanguageComboBox.addItems(languages)
+        for language in languages:
+            self.lexerLanguageComboBox.addItem(
+                QScintilla.Lexers.getLanguageIcon(language, False),
+                language)
         self.on_lexerLanguageComboBox_activated("")
         
     def save(self):
