@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -11,7 +11,7 @@ from __future__ import unicode_literals
 
 from PyQt5.QtCore import pyqtSlot
 from PyQt5.QtGui import QColor, QPalette
-from PyQt5.QtWidgets import QColorDialog
+from PyQt5.QtWidgets import QColorDialog, QFontDialog
 from PyQt5.Qsci import QsciScintilla
 
 from .ConfigurationPageBase import ConfigurationPageBase
@@ -19,6 +19,11 @@ from .Ui_EditorStylesPage import Ui_EditorStylesPage
 
 import Preferences
 
+try:
+    MonospacedFontsOption = QFontDialog.MonospacedFonts
+except AttributeError:
+    MonospacedFontsOption = QFontDialog.FontDialogOptions(0x10)
+
 
 class EditorStylesPage(ConfigurationPageBase, Ui_EditorStylesPage):
     """
@@ -191,6 +196,8 @@ class EditorStylesPage(ConfigurationPageBase, Ui_EditorStylesPage):
         
         self.miniMenuCheckBox.setChecked(
             Preferences.getEditor("MiniContextMenu"))
+        self.hideFormatButtonsCheckBox.setChecked(
+            Preferences.getEditor("HideFormatButtons"))
         
         self.enableAnnotationsCheckBox.setChecked(
             Preferences.getEditor("AnnotationsEnabled"))
@@ -319,6 +326,8 @@ class EditorStylesPage(ConfigurationPageBase, Ui_EditorStylesPage):
         
         Preferences.setEditor(
             "MiniContextMenu", self.miniMenuCheckBox.isChecked())
+        Preferences.setEditor(
+            "HideFormatButtons", self.hideFormatButtonsCheckBox.isChecked())
         
         Preferences.setEditor(
             "AnnotationsEnabled", self.enableAnnotationsCheckBox.isChecked())
@@ -347,7 +356,8 @@ class EditorStylesPage(ConfigurationPageBase, Ui_EditorStylesPage):
         Private method used to select the font for the editor margins.
         """
         self.marginsFont = self.selectFont(
-            self.marginsFontSample, self.marginsFont)
+            self.marginsFontSample, self.marginsFont,
+            options=MonospacedFontsOption)
         
     @pyqtSlot()
     def on_defaultFontButton_clicked(self):
@@ -364,7 +374,8 @@ class EditorStylesPage(ConfigurationPageBase, Ui_EditorStylesPage):
         font.
         """
         self.monospacedFont = self.selectFont(
-            self.monospacedFontSample, self.monospacedFont)
+            self.monospacedFontSample, self.monospacedFont,
+            options=MonospacedFontsOption)
         
     def polishPage(self):
         """
