@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -137,33 +137,39 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
         # 2a. Translation Extractor PyQt4
         self.__createProgramEntry(
             self.tr("Translation Extractor (Python, PyQt4)"),
-            Utilities.isWindowsPlatform() and "pylupdate4.exe" or "pylupdate4",
+            Utilities.isWindowsPlatform() and
+            Utilities.getWindowsExecutablePath("pylupdate4") or "pylupdate4",
             '-version', 'pylupdate', -1)
         # 2b. Forms Compiler PyQt4
         self.__createProgramEntry(
             self.tr("Forms Compiler (Python, PyQt4)"),
-            Utilities.isWindowsPlatform() and "pyuic4.bat" or "pyuic4",
+            Utilities.isWindowsPlatform() and
+            Utilities.getWindowsExecutablePath("pyuic4") or "pyuic4",
             '--version', 'Python User', 4)
         # 2c. Resource Compiler PyQt4
         self.__createProgramEntry(
             self.tr("Resource Compiler (Python, PyQt4)"),
-            Utilities.isWindowsPlatform() and "pyrcc4.exe" or "pyrcc4",
+            Utilities.isWindowsPlatform() and
+            Utilities.getWindowsExecutablePath("pyrcc4") or "pyrcc4",
             '-version', 'Resource Compiler', -1)
         # 2d. Translation Extractor PyQt5
         self.__createProgramEntry(
             self.tr("Translation Extractor (Python, PyQt5)"),
-            Utilities.isWindowsPlatform() and "pylupdate5.exe" or "pylupdate5",
+            Utilities.isWindowsPlatform() and
+            Utilities.getWindowsExecutablePath("pylupdate5") or "pylupdate5",
             '-version', 'pylupdate', -1)
         # 2e. Forms Compiler PyQt5
         self.__createProgramEntry(
             self.tr("Forms Compiler (Python, PyQt5)"),
-            Utilities.isWindowsPlatform() and "pyuic5.bat" or "pyuic5",
+            Utilities.isWindowsPlatform() and
+            Utilities.getWindowsExecutablePath("pyuic5") or "pyuic5",
             '--version', 'Python User', 4)
         # 2f. Resource Compiler PyQt5
         self.__createProgramEntry(
             self.tr("Resource Compiler (Python, PyQt5)"),
-            Utilities.isWindowsPlatform() and "pyrcc5.exe" or "pyrcc5",
-            '-version', 'Resource Compiler', -1)
+            Utilities.isWindowsPlatform() and
+            Utilities.getWindowsExecutablePath("pyrcc5") or "pyrcc5",
+            '-version', '', -1, versionRe='Resource Compiler|pyrcc5')
         
         # 3. do the PySide programs
         # 3a. Translation Extractor PySide
