@@ -486,8 +486,8 @@ class ProjectInterfacesBrowser(ProjectBaseBrowser):
             poaList = glob.glob(os.path.join(path, "*__POA"))
             npoaList = [f.replace("__POA", "") for f in poaList]
             fileList = glob.glob(os.path.join(path, "*_idl.py"))
-            for dir in poaList + npoaList:
-                fileList += Utilities.direntries(dir, True, "*.py")
+            for directory in poaList + npoaList:
+                fileList += Utilities.direntries(directory, True, "*.py")
             for file in fileList:
                 self.project.appendFile(file)
             if not self.noDialog and not ui.notificationsEnabled():
