@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -998,15 +998,15 @@ class Shell(QsciScintillaCompat):
         if pinch:
             if pinch.state() == Qt.GestureStarted:
                 zoom = (self.getZoom() + 10) / 10.0
-                pinch.setScaleFactor(zoom)
-            else:
-                zoom = int(pinch.scaleFactor() * 10) - 10
+                pinch.setTotalScaleFactor(zoom)
+            elif pinch.state() == Qt.GestureUpdated:
+                zoom = int(pinch.totalScaleFactor() * 10) - 10
                 if zoom <= -9:
                     zoom = -9
-                    pinch.setScaleFactor(0.1)
+                    pinch.setTotalScaleFactor(0.1)
                 elif zoom >= 20:
                     zoom = 20
-                    pinch.setScaleFactor(3.0)
+                    pinch.setTotalScaleFactor(3.0)
                 self.zoomTo(zoom)
             evt.accept()
     
@@ -1446,14 +1446,14 @@ class Shell(QsciScintillaCompat):
         else:
             if not self.echoInput:
                 cmd = self.buff
+                self.buff = ""
+            elif cmd:
+                cmd = cmd[len(self.prompt):]
             self.inRawMode = False
             self.echoInput = True
-            if not cmd:
-                cmd = ''
-            else:
-                cmd = cmd[len(self.prompt):]
+            
             self.dbs.remoteRawInput(cmd)
-        
+    
     def __useHistory(self):
         """
         Private method to display a command from the history.
@@ -1513,20 +1513,20 @@ class Shell(QsciScintillaCompat):
             idx -= 1
         return idx
         
-    def focusNextPrevChild(self, next):
+    def focusNextPrevChild(self, nextChild):
         """
         Public method to stop Tab moving to the next window.
         
         While the user is entering a multi-line command, the movement to
         the next window by the Tab key being pressed is suppressed.
         
-        @param next next window
+        @param nextChild next window
         @return flag indicating the movement
         """
-        if next and self.inContinue:
+        if nextChild and self.inContinue:
             return False
         
-        return QsciScintillaCompat.focusNextPrevChild(self, next)
+        return QsciScintillaCompat.focusNextPrevChild(self, nextChild)
         
     def contextMenuEvent(self, ev):
         """
@@ -1621,14 +1621,14 @@ class Shell(QsciScintillaCompat):
             self.__insertText(txt)
             self.completionText = ""
         
-    def __completionListSelected(self, id, txt):
+    def __completionListSelected(self, listId, txt):
         """
         Private slot to handle the selection from the completion list.
         
-        @param id the ID of the user list (should be 1) (integer)
+        @param listId the ID of the user list (should be 1) (integer)
         @param txt the selected text (string)
         """
-        if id == 1:
+        if listId == 1:
             if self.completionText != "":
                 txt = txt.replace(self.completionText, "")
             self.__insertText(txt)
