@@ -456,16 +456,16 @@ class UIPreviewer(E5MainWindow):
         defaultExt = "PNG"
         filters = ""
         formats = QImageWriter.supportedImageFormats()
-        for format in formats:
+        for imageFormat in formats:
             filters = "{0}*.{1} ".format(
-                filters, bytes(format).decode().lower())
-        filter = self.tr("Images ({0})").format(filters[:-1])
+                filters, bytes(imageFormat).decode().lower())
+        fileFilter = self.tr("Images ({0})").format(filters[:-1])
         
         fname = E5FileDialog.getSaveFileName(
             self,
             self.tr("Save Image"),
             "",
-            filter)
+            fileFilter)
         if not fname:
             return
             
