@@ -208,7 +208,8 @@ class Browser(QTreeView):
             self.handleUnittest)
         self.sourceMenu.addSeparator()
         self.mimeTypeAct = self.sourceMenu.addAction(
-            self.tr('Show Mime-Type'), self.__showMimeType)
+            QCoreApplication.translate('Browser', 'Show Mime-Type'),
+            self.__showMimeType)
         self.sourceMenu.addSeparator()
         self.sourceMenu.addAction(
             QCoreApplication.translate('Browser', 'Copy Path to Clipboard'),
@@ -226,7 +227,8 @@ class Browser(QTreeView):
             self._editPixmap)
         self.menu.addSeparator()
         self.mimeTypeAct = self.menu.addAction(
-            self.tr('Show Mime-Type'), self.__showMimeType)
+            QCoreApplication.translate('Browser', 'Show Mime-Type'),
+            self.__showMimeType)
         self.menu.addSeparator()
         self.menu.addAction(
             QCoreApplication.translate('Browser', 'Copy Path to Clipboard'),
@@ -280,7 +282,8 @@ class Browser(QTreeView):
                 self.__configure)
         
         # create the attribute menu
-        self.gotoMenu = QMenu(self.tr("Goto"), self)
+        self.gotoMenu = QMenu(QCoreApplication.translate('Browser', "Goto"),
+                              self)
         self.gotoMenu.aboutToShow.connect(self._showGotoMenu)
         self.gotoMenu.triggered.connect(self._gotoAttribute)
         
@@ -394,7 +397,8 @@ class Browser(QTreeView):
         
         for lineno in sorted(linenos):
             act = self.gotoMenu.addAction(
-                self.tr("Line {0}".format(lineno)))
+                QCoreApplication.translate(
+                    'Browser', "Line {0}").format(lineno))
             act.setData([fileName, lineno])
         
     def _gotoAttribute(self, act):
@@ -487,30 +491,40 @@ class Browser(QTreeView):
             if mimetype is None:
                 E5MessageBox.warning(
                     self,
-                    self.tr("Show Mime-Type"),
-                    self.tr("""The mime type of the file could not be"""
-                            """ determined."""))
+                    QCoreApplication.translate('Browser', "Show Mime-Type"),
+                    QCoreApplication.translate(
+                        'Browser',
+                        """The mime type of the file could not be"""
+                        """ determined."""))
             elif mimetype.split("/")[0] == "text":
                 E5MessageBox.information(
                     self,
-                    self.tr("Show Mime-Type"),
-                    self.tr("""The file has the mime type <b>{0}</b>.""")
+                    QCoreApplication.translate('Browser', "Show Mime-Type"),
+                    QCoreApplication.translate(
+                        'Browser',
+                        """The file has the mime type <b>{0}</b>.""")
                     .format(mimetype))
             else:
                 textMimeTypesList = Preferences.getUI("TextMimeTypes")
                 if mimetype in textMimeTypesList:
                     E5MessageBox.information(
                         self,
-                        self.tr("Show Mime-Type"),
-                        self.tr("""The file has the mime type <b>{0}</b>.""")
+                        QCoreApplication.translate(
+                            'Browser', "Show Mime-Type"),
+                        QCoreApplication.translate(
+                            'Browser',
+                            """The file has the mime type <b>{0}</b>.""")
                         .format(mimetype))
                 else:
                     ok = E5MessageBox.yesNo(
                         self,
-                        self.tr("Show Mime-Type"),
-                        self.tr("""The file has the mime type <b>{0}</b>."""
-                                """<br/> Shall it be added to the list of"""
-                                """ text mime types?""").format(mimetype))
+                        QCoreApplication.translate(
+                            'Browser', "Show Mime-Type"),
+                        QCoreApplication.translate(
+                            'Browser',
+                            """The file has the mime type <b>{0}</b>."""
+                            """<br/> Shall it be added to the list of"""
+                            """ text mime types?""").format(mimetype))
                     if ok:
                         textMimeTypesList.append(mimetype)
                         Preferences.setUI("TextMimeTypes", textMimeTypesList)
@@ -640,26 +654,26 @@ class Browser(QTreeView):
         """
         self.__model.interpreterChanged(interpreter)
         
-    def wantedItem(self, itm, filter=None):
+    def wantedItem(self, itm, filterList=None):
         """
         Public method to check type of an item.
         
         @param itm the item to check (BrowserItem)
-        @param filter list of classes to check against
+        @param filterList list of classes to check against
         @return flag indicating item is a valid type (boolean)
         """
-        if filter is None:
-            filter = self.selectedItemsFilter
-        for typ in filter:
+        if filterList is None:
+            filterList = self.selectedItemsFilter
+        for typ in filterList:
             if isinstance(itm, typ):
                 return True
         return False
         
-    def getSelectedItems(self, filter=None):
+    def getSelectedItems(self, filterList=None):
         """
         Public method to get the selected items.
         
-        @param filter list of classes to check against
+        @param filterList list of classes to check against
         @return list of selected items (list of BroweserItem)
         """
         selectedItems = []
@@ -667,15 +681,15 @@ class Browser(QTreeView):
         for index in indexes:
             if index.column() == 0:
                 itm = self.model().item(index)
-                if self.wantedItem(itm, filter):
+                if self.wantedItem(itm, filterList):
                     selectedItems.append(itm)
         return selectedItems
         
-    def getSelectedItemsCount(self, filter=None):
+    def getSelectedItemsCount(self, filterList=None):
         """
         Public method to get the count of items selected.
         
-        @param filter list of classes to check against
+        @param filterList list of classes to check against
         @return count of items selected (integer)
         """
         count = 0
@@ -683,15 +697,15 @@ class Browser(QTreeView):
         for index in indexes:
             if index.column() == 0:
                 itm = self.model().item(index)
-                if self.wantedItem(itm, filter):
+                if self.wantedItem(itm, filterList):
                     count += 1
         return count
         
-    def getSelectedItemsCountCategorized(self, filter=None):
+    def getSelectedItemsCountCategorized(self, filterList=None):
         """
         Public method to get a categorized count of selected items.
         
-        @param filter list of classes to check against
+        @param filterList list of classes to check against
         @return a dictionary containing the counts of items belonging
             to the individual filter classes. The keys of the dictionary
             are the string representation of the classes given in the
@@ -699,18 +713,18 @@ class Browser(QTreeView):
             an additional entry with key "sum", that stores the sum of
             all selected entries fulfilling the filter criteria.
         """
-        if filter is None:
-            filter = self.selectedItemsFilter
+        if filterList is None:
+            filterList = self.selectedItemsFilter
         categories = {}
         categories["sum"] = 0
-        for typ in filter:
+        for typ in filterList:
             categories[str(typ)] = 0
         
         indexes = self.selectedIndexes()
         for index in indexes:
             if index.column() == 0:
                 itm = self.model().item(index)
-                for typ in filter:
+                for typ in filterList:
                     if isinstance(itm, typ):
                         categories["sum"] += 1
                         categories[str(typ)] += 1
