@@ -68,13 +68,16 @@ class BrowserModel(QAbstractItemModel):
             
             self.__populateModel()
     
-    def columnCount(self, parent=QModelIndex()):
+    def columnCount(self, parent=None):
         """
         Public method to get the number of columns.
         
         @param parent index of parent item (QModelIndex)
         @return number of columns (integer)
         """
+        if parent is None:
+            parent = QModelIndex()
+        
         if parent.isValid():
             item = parent.internalPointer()
         else:
@@ -143,7 +146,7 @@ class BrowserModel(QAbstractItemModel):
         
         return None
     
-    def index(self, row, column, parent=QModelIndex()):
+    def index(self, row, column, parent=None):
         """
         Public method to create an index.
         
@@ -152,6 +155,9 @@ class BrowserModel(QAbstractItemModel):
         @param parent index of parent item (QModelIndex)
         @return index object (QModelIndex)
         """
+        if parent is None:
+            parent = QModelIndex()
+        
         # The model/view framework considers negative values out-of-bounds,
         # however in python they work when indexing into lists. So make sure
         # we return an invalid index for out-of-bounds row/col
@@ -193,13 +199,16 @@ class BrowserModel(QAbstractItemModel):
         
         return self.createIndex(parentItem.row(), 0, parentItem)
     
-    def rowCount(self, parent=QModelIndex()):
+    def rowCount(self, parent=None):
         """
         Public method to get the number of rows.
         
         @param parent index of parent item (QModelIndex)
         @return number of rows (integer)
         """
+        if parent is None:
+            parent = QModelIndex()
+        
         # Only the first column should have children
         if parent.column() > 0:
             return 0
@@ -213,7 +222,7 @@ class BrowserModel(QAbstractItemModel):
         
         return parentItem.childCount()
 
-    def hasChildren(self, parent=QModelIndex()):
+    def hasChildren(self, parent=None):
         """
         Public method to check for the presence of child items.
         
@@ -223,6 +232,9 @@ class BrowserModel(QAbstractItemModel):
         @param parent index of parent item (QModelIndex)
         @return flag indicating the presence of child items (boolean)
         """
+        if parent is None:
+            parent = QModelIndex()
+        
         # Only the first column should have children
         if parent.column() > 0:
             return 0
@@ -300,17 +312,18 @@ class BrowserModel(QAbstractItemModel):
             return
         
         if Preferences.getUI("BrowsersListHiddenFiles"):
-            filter = QDir.Filters(
+            dirFilter = QDir.Filters(
                 QDir.AllEntries | QDir.Hidden | QDir.NoDotAndDotDot)
         else:
-            filter = QDir.Filters(QDir.AllEntries | QDir.NoDot | QDir.NoDotDot)
+            dirFilter = QDir.Filters(
+                QDir.AllEntries | QDir.NoDot | QDir.NoDotDot)
         
         for itm in self.watchedItems[path]:
             oldCnt = itm.childCount()
             
             qdir = QDir(itm.dirName())
             
-            entryInfoList = qdir.entryInfoList(filter)
+            entryInfoList = qdir.entryInfoList(dirFilter)
             
             # step 1: check for new entries
             children = itm.children()
@@ -482,13 +495,16 @@ class BrowserModel(QAbstractItemModel):
         """
         parentItem.appendChild(itm)
     
-    def addItem(self, itm, parent=QModelIndex()):
+    def addItem(self, itm, parent=None):
         """
         Public slot to add an item.
         
         @param itm item to add (BrowserItem)
         @param parent index of parent item (QModelIndex)
         """
+        if parent is None:
+            parent = QModelIndex()
+        
         if not parent.isValid():
             parentItem = self.rootItem
         else:
@@ -531,11 +547,12 @@ class BrowserModel(QAbstractItemModel):
         qdir = QDir(parentItem.dirName())
         
         if Preferences.getUI("BrowsersListHiddenFiles"):
-            filter = QDir.Filters(
+            dirFilter = QDir.Filters(
                 QDir.AllEntries | QDir.Hidden | QDir.NoDotAndDotDot)
         else:
-            filter = QDir.Filters(QDir.AllEntries | QDir.NoDot | QDir.NoDotDot)
-        entryInfoList = qdir.entryInfoList(filter)
+            dirFilter = QDir.Filters(
+                QDir.AllEntries | QDir.NoDot | QDir.NoDotDot)
+        entryInfoList = qdir.entryInfoList(dirFilter)
         if len(entryInfoList) > 0:
             if repopulate:
                 self.beginInsertRows(
@@ -552,8 +569,8 @@ class BrowserModel(QAbstractItemModel):
                         Preferences.getUI("BrowsersFileFilters").split(";")
                     if fileFilters:
                         fn = f.fileName()
-                        if any([fnmatch.fnmatch(fn, ff.strip())
-                                for ff in fileFilters]):
+                        if any(fnmatch.fnmatch(fn, ff.strip())
+                               for ff in fileFilters):
                             continue
                     node = BrowserFileItem(
                         parentItem,
@@ -606,13 +623,13 @@ class BrowserModel(QAbstractItemModel):
         moduleName = parentItem.moduleName()
         fileName = parentItem.fileName()
         try:
-            dict = Utilities.ClassBrowsers.readmodule(
+            dictionary = Utilities.ClassBrowsers.readmodule(
                 moduleName, [parentItem.dirName()],
                 parentItem.isPython2File() or parentItem.isPython3File())
         except ImportError:
             return
         
-        keys = list(dict.keys())
+        keys = list(dictionary.keys())
         if len(keys) > 0:
             if repopulate:
                 self.beginInsertRows(
@@ -622,7 +639,7 @@ class BrowserModel(QAbstractItemModel):
                 if key.startswith("@@"):
                     # special treatment done later
                     continue
-                cl = dict[key]
+                cl = dictionary[key]
                 try:
                     if cl.module == moduleName:
                         node = BrowserClassItem(parentItem, cl, fileName)
@@ -633,12 +650,12 @@ class BrowserModel(QAbstractItemModel):
                 node = BrowserCodingItem(
                     parentItem,
                     QCoreApplication.translate("BrowserModel", "Coding: {0}")
-                    .format(dict["@@Coding@@"].coding))
+                    .format(dictionary["@@Coding@@"].coding))
                 self._addItem(node, parentItem)
             if "@@Globals@@" in keys:
                 node = BrowserGlobalsItem(
                     parentItem,
-                    dict["@@Globals@@"].globals,
+                    dictionary["@@Globals@@"].globals,
                     QCoreApplication.translate("BrowserModel", "Globals"))
                 self._addItem(node, parentItem)
             if "@@Import@@" in keys or "@@ImportFrom@@" in keys:
@@ -648,7 +665,7 @@ class BrowserModel(QAbstractItemModel):
                 self._addItem(node, parentItem)
                 if "@@Import@@" in keys:
                     for importedModule in \
-                            dict["@@Import@@"].getImports().values():
+                            dictionary["@@Import@@"].getImports().values():
                         m_node = BrowserImportItem(
                             node,
                             importedModule.importedModuleName,
