@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -14,7 +14,8 @@ import os
 from PyQt5.QtCore import pyqtSignal, pyqtSlot, Qt, QUrl, QDir, QFile, \
     QFileDevice, QTemporaryFile, qVersion
 from PyQt5.QtGui import QIcon, QPixmap, QPainter
-from PyQt5.QtWidgets import QWidget, QHBoxLayout, QMenu, QToolButton, QDialog
+from PyQt5.QtWidgets import QWidget, QHBoxLayout, QMenu, QToolButton, \
+    QDialog, QApplication
 from PyQt5.QtPrintSupport import QPrinter, QPrintDialog, QAbstractPrintDialog
 
 from E5Gui.E5TabWidget import E5TabWidget
@@ -183,11 +184,18 @@ class WebBrowserTabWidget(E5TabWidget):
         self.__tabContextMenu.addAction(
             self.tr('Close All'), self.closeAllBrowsers)
         self.__tabContextMenu.addSeparator()
-        if not Globals.isWindowsPlatform() and qVersion() < "5.7.0":
+        # TODO: re-check this once printing on Windows is reliable
+##        if qVersion() >= "5.8.0" or (
+##                not Globals.isWindowsPlatform() and qVersion() < "5.7.0"):
+        if not Globals.isWindowsPlatform() and (
+                qVersion() < "5.7.0" or qVersion() >= "5.8.0"):
             self.__tabContextMenu.addAction(
                 UI.PixmapCache.getIcon("printPreview.png"),
                 self.tr('Print Preview'), self.__tabContextMenuPrintPreview)
-        if not Globals.isWindowsPlatform() or qVersion() >= "5.7.0":
+        # TODO: re-check this once printing on Windows is reliable
+##        if qVersion() >= "5.8.0" or (
+##                not Globals.isWindowsPlatform() or qVersion() >= "5.7.0"):
+        if not Globals.isWindowsPlatform() and qVersion() >= "5.7.0":
             self.__tabContextMenu.addAction(
                 UI.PixmapCache.getIcon("print.png"),
                 self.tr('Print'), self.__tabContextMenuPrint)
@@ -639,9 +647,11 @@ class WebBrowserTabWidget(E5TabWidget):
                 printDialog.setOption(QAbstractPrintDialog.PrintCollateCopies)
             printDialog.setOption(QAbstractPrintDialog.PrintPageRange)
         if printDialog.exec_() == QDialog.Accepted:
-            if not hasattr(browser.page(), "printToPdf"):
-                browser.render(printer)
-            else:
+            if hasattr(browser.page(), "print"):
+                # Qt >= 5.8.0
+                browser.page().execPrintPage(printer)
+            elif hasattr(browser.page(), "printToPdf"):
+                # Qt >= 5.7.0
                 if printer.outputFormat() == QPrinter.PdfFormat:
                     # print to PDF file selected
                     browser.page().printToPdf(
@@ -654,6 +664,8 @@ class WebBrowserTabWidget(E5TabWidget):
                     browser.page().printToPdf(
                         self.__pdfGeneratedForPrinting,
                         printer.pageLayout())
+            else:
+                browser.render(printer)
     
     @pyqtSlot()
     def printBrowserPdf(self, browser=None):
@@ -774,7 +786,7 @@ class WebBrowserTabWidget(E5TabWidget):
         """
         Public slot called to show a print preview of the displayed file.
         
-        @param browser reference to the browser to be printed (HelpBrowserWV)
+        @param browser reference to the browser to be printed (WebBrowserView)
         """
         from PyQt5.QtPrintSupport import QPrintPreviewDialog
         
@@ -803,9 +815,27 @@ class WebBrowserTabWidget(E5TabWidget):
         printer.setResolution(Preferences.getPrinter("Resolution"))
         
         preview = QPrintPreviewDialog(printer, self)
-        preview.paintRequested.connect(lambda p: browser.render(p))
+        preview.resize(800, 750)
+        if qVersion() >= "5.8.0":
+            preview.paintRequested.connect(
+                lambda p: self.__printPreviewRequested(p, browser))
+        else:
+            preview.paintRequested.connect(lambda p: browser.render(p))
         preview.exec_()
     
+    def __printPreviewRequested(self, printer, browser):
+        """
+        Private slot to generate the print preview.
+        
+        @param printer reference to the printer object
+        @type QPrinter
+        @param browser reference to the browser to be printed
+        @type WebBrowserView
+        """
+        QApplication.setOverrideCursor(Qt.WaitCursor)
+        browser.page().execPrintPage(printer, 10 * 1000)
+        QApplication.restoreOverrideCursor()
+    
     def __sourceChanged(self, url):
         """
         Private slot to handle a change of a browsers source.
