@@ -17,13 +17,14 @@ except NameError:
 import os
 
 from PyQt5.QtCore import pyqtSignal, QUrl, QFileInfo, Qt, QTimer, QEvent, \
-    QPoint, QDateTime, qVersion
+    QPoint, QDateTime, qVersion, QStandardPaths
 from PyQt5.QtGui import QDesktopServices, QClipboard, QIcon, \
     QContextMenuEvent, QPixmap
 from PyQt5.QtWidgets import qApp, QStyle, QMenu, QApplication
-from PyQt5.QtWebEngineWidgets import QWebEngineView, QWebEnginePage
+from PyQt5.QtWebEngineWidgets import QWebEngineView, QWebEnginePage, \
+    QWebEngineDownloadItem
 
-from E5Gui import E5MessageBox
+from E5Gui import E5MessageBox, E5FileDialog
 
 from WebBrowser.WebBrowserWindow import WebBrowserWindow
 from .WebBrowserPage import WebBrowserPage
@@ -121,8 +122,26 @@ class WebBrowserView(QWebEngineView):
         self.__inspector = None
         WebInspector.registerView(self)
         
+        if qVersion() >= "5.8.0":
+            lay = self.layout()
+            lay.currentChanged.connect(
+                lambda: QTimer.singleShot(0, self.__setRwhvqt))
+            self.__setRwhvqt()
+        
         self.grabGesture(Qt.PinchGesture)
     
+    def __setRwhvqt(self):
+        """
+        Private slot to set widget that receives input events.
+        """
+        self.grabGesture(Qt.PinchGesture)
+        self.__rwhvqt = self.focusProxy()
+        if self.__rwhvqt:
+            self.__rwhvqt.grabGesture(Qt.PinchGesture)
+            self.__rwhvqt.installEventFilter(self)
+        else:
+            print("Focus proxy is null!")   # __IGNORE_WARNING_M801__
+    
     def __currentEngineChanged(self):
         """
         Private slot to track a change of the current search engine.
@@ -502,6 +521,28 @@ class WebBrowserView(QWebEngineView):
         @param hitTest reference to the hit test object
         @type WebHitTestResult
         """
+        spellCheckActionCount = 0
+        if qVersion() >= "5.7.0":
+            contextMenuData = self.page().contextMenuData()
+            hitTest.updateWithContextMenuData(contextMenuData)
+            
+            if qVersion() >= "5.8.0" and \
+               bool(contextMenuData.misspelledWord()):
+                boldFont = menu.font()
+                boldFont.setBold(True)
+                
+                for suggestion in contextMenuData.spellCheckerSuggestions():
+                    act = menu.addAction(
+                        suggestion,
+                        self.__replaceMisspelledWord)
+                    act.setFont(boldFont)
+                
+                if bool(menu.actions()):
+                    menu.addAction(self.tr("No suggestions")).setEnabled(False)
+                
+                menu.addSeparator()
+                spellCheckActionCount = len(menu.actions())
+        
         if not hitTest.linkUrl().isEmpty() and \
                 hitTest.linkUrl().scheme() != "javascript":
             self.__createLinkContextMenu(menu, hitTest)
@@ -513,15 +554,17 @@ class WebBrowserView(QWebEngineView):
             self.__createMediaContextMenu(menu, hitTest)
         
         if hitTest.isContentEditable():
-            menu.addAction(self.__mw.undoAct)
-            menu.addAction(self.__mw.redoAct)
-            menu.addSeparator()
-            menu.addAction(self.__mw.cutAct)
-            menu.addAction(self.__mw.copyAct)
-            menu.addAction(self.__mw.pasteAct)
-            menu.addSeparator()
-            self.__mw.personalInformationManager().createSubMenu(
-                menu, self, hitTest)
+            # check, if only spell checker actions were added
+            if len(menu.actions()) == spellCheckActionCount:
+                menu.addAction(self.__mw.undoAct)
+                menu.addAction(self.__mw.redoAct)
+                menu.addSeparator()
+                menu.addAction(self.__mw.cutAct)
+                menu.addAction(self.__mw.copyAct)
+                menu.addAction(self.__mw.pasteAct)
+                menu.addSeparator()
+                self.__mw.personalInformationManager().createSubMenu(
+                    menu, self, hitTest)
             
             if hitTest.tagName() == "input":
                 menu.addSeparator()
@@ -903,6 +946,14 @@ class WebBrowserView(QWebEngineView):
             bool(url.scheme()) and \
             "." in url.host()
     
+    def __replaceMisspelledWord(self):
+        """
+        Private slot to replace a misspelled word under the context menu.
+        """
+        act = self.sender()
+        suggestion = act.text()
+        self.page().replaceMisspelledWord(suggestion)
+    
     def __openLinkInNewTab(self):
         """
         Private method called by the context menu to open a link in a new
@@ -1320,9 +1371,9 @@ class WebBrowserView(QWebEngineView):
         pinch = evt.gesture(Qt.PinchGesture)
         if pinch:
             if pinch.state() == Qt.GestureStarted:
-                pinch.setScaleFactor(self.__currentZoom / 100.0)
-            else:
-                scaleFactor = pinch.scaleFactor()
+                pinch.setTotalScaleFactor(self.__currentZoom / 100.0)
+            elif pinch.state() == Qt.GestureUpdated:
+                scaleFactor = pinch.totalScaleFactor()
                 self.setZoomValue(int(scaleFactor * 100))
             evt.accept()
     
@@ -1338,14 +1389,16 @@ class WebBrowserView(QWebEngineView):
         @rtype bool
         """
         # find the render widget receiving events for the web page
-        if obj is self and evt.type() == QEvent.ChildAdded:
-            child = evt.child()
-            if child and child.inherits(
-                    "QtWebEngineCore::RenderWidgetHostViewQtDelegateWidget"):
-                self.__rwhvqt = child
-                self.grabGesture(Qt.PinchGesture)
-                self.__rwhvqt.grabGesture(Qt.PinchGesture)
-                self.__rwhvqt.installEventFilter(self)
+        if qVersion() < "5.8.0":
+            if obj is self and evt.type() == QEvent.ChildAdded:
+                child = evt.child()
+                if child and child.inherits(
+                        "QtWebEngineCore::"
+                        "RenderWidgetHostViewQtDelegateWidget"):
+                    self.__rwhvqt = child
+                    self.grabGesture(Qt.PinchGesture)
+                    self.__rwhvqt.grabGesture(Qt.PinchGesture)
+                    self.__rwhvqt.installEventFilter(self)
         
         # forward events to WebBrowserView
         if obj is self.__rwhvqt:
@@ -1474,12 +1527,19 @@ class WebBrowserView(QWebEngineView):
         if status == QWebEnginePage.NormalTerminationStatus:
             return
         
-        QTimer.singleShot(0, self.__showTabCrashPage)
+        QTimer.singleShot(0, lambda: self.__showTabCrashPage(status))
     
-    def __showTabCrashPage(self):
+    def __showTabCrashPage(self, status):
         """
         Private slot to show the tab crash page.
+        
+        @param status termination status
+        @type QWebEnginePage.RenderProcessTerminationStatus
         """
+        self.page().deleteLater()
+        self.__page = WebBrowserPage(self)
+        self.setPage(self.__page)
+        
         html = readAllFileContents(":/html/tabCrashPage.html")
         html = html.replace("@IMAGE@", pixmapToDataUrl(
             qApp.style().standardIcon(QStyle.SP_MessageBoxWarning).pixmap(
@@ -1487,18 +1547,24 @@ class WebBrowserView(QWebEngineView):
         html = html.replace("@FAVICON@", pixmapToDataUrl(
             qApp.style() .standardIcon(QStyle.SP_MessageBoxWarning).pixmap(
                 16, 16)).toString())
-        html = html.replace("@TITLE@", self.tr("Failed loading page"))
-        html = html.replace("@H1@", self.tr("Failed loading page"))
         html = html.replace(
-            "@LI-1@",
-            self.tr("Something went wrong while loading this page."))
+            "@TITLE@", self.tr("Render Process terminated abnormally"))
+        html = html.replace(
+            "@H1@", self.tr("Render Process terminated abnormally"))
+        if status == QWebEnginePage.CrashedTerminationStatus:
+            msg = self.tr("The render process crashed while"
+                          " loading this page.")
+        elif status == QWebEnginePage.KilledTerminationStatus:
+            msg = self.tr("The render process was killed.")
+        else:
+            msg = self.tr("The render process terminated while"
+                          " loading this page.")
+        html = html.replace("@LI-1@", msg)
         html = html.replace(
             "@LI-2@",
             self.tr(
                 "Try reloading the page or closing some tabs to make more"
                 " memory available."))
-        html = html.replace(
-            "@BUTTON@", self.tr("Reload Page"))
         self.page().setHtml(html, self.url())
     
     def __loadStarted(self):
@@ -1600,7 +1666,76 @@ class WebBrowserView(QWebEngineView):
         if url.isEmpty():
             return
         
-        self.triggerPageAction(QWebEnginePage.SavePage)
+        if qVersion() >= "5.8.0":
+            # since Qt 5.8.0
+            fileName, savePageFormat = self.__getSavePageFileNameAndFormat()
+            if fileName:
+                self.page().save(fileName, savePageFormat)
+        else:
+            self.triggerPageAction(QWebEnginePage.SavePage)
+    
+    def __getSavePageFileNameAndFormat(self):
+        """
+        Private method to get the file name to save the page to.
+        
+        @return tuple containing the file name to save to and the
+            save page format
+        @rtype tuple of (str, QWebEngineDownloadItem.SavePageFormat)
+        """
+        documentLocation = QStandardPaths.writableLocation(
+            QStandardPaths.DocumentsLocation)
+        filterList = [
+            self.tr("Web Archive (*.mhtml *.mht)"),
+            self.tr("HTML File (*.html *.htm)"),
+            self.tr("HTML File with all resources (*.html *.htm)"),
+        ]
+        extensionsList = [
+            # tuple of extensions for *nix and Windows
+            # keep in sync with filters list
+            (".mhtml", ".mht"),
+            (".html", ".htm"),
+            (".html", ".htm"),
+        ]
+        if self.url().fileName():
+            defaultFileName = os.path.join(documentLocation,
+                                           self.url().fileName())
+        else:
+            defaultFileName = os.path.join(documentLocation,
+                                           self.page().title())
+            if Utilities.isWindowsPlatform():
+                defaultFileName += ".mht"
+            else:
+                defaultFileName += ".mhtml"
+
+        fileName = ""
+        saveFormat = QWebEngineDownloadItem.MimeHtmlSaveFormat
+        
+        fileName, selectedFilter = E5FileDialog.getSaveFileNameAndFilter(
+            None,
+            self.tr("Save Web Page"),
+            defaultFileName,
+            ";;".join(filterList),
+            None)
+        if fileName:
+            index = filterList.index(selectedFilter)
+            if index == 0:
+                saveFormat = QWebEngineDownloadItem.MimeHtmlSaveFormat
+            elif index == 1:
+                saveFormat = QWebEngineDownloadItem.SingleHtmlSaveFormat
+            else:
+                saveFormat = QWebEngineDownloadItem.CompleteHtmlSaveFormat
+            
+            extension = os.path.splitext(fileName)[1]
+            if not extension:
+                # add the platform specific default extension
+                if Utilities.isWindowsPlatform():
+                    extensionsIndex = 1
+                else:
+                    extensionsIndex = 0
+                extensions = extensionsList[index]
+                fileName += extensions[extensionsIndex]
+        
+        return fileName, saveFormat
     
     ###########################################################################
     ## Miscellaneous methods below
