@@ -133,7 +133,8 @@ def handleSingleApplication(ddindex):
             client.processArgs(sys.argv[1:])
         sys.exit(0)
     elif res < 0:
-        print("eric6: {0}".format(client.errstr()))     # __IGNORE_WARNING__
+        print("eric6: {0}".format(client.errstr()))
+        # __IGNORE_WARNING_M801__
         sys.exit(res)
 
 
@@ -194,7 +195,7 @@ def excepthook(excType, excValue, tracebackobj):
             msg = msg.encode(sys.stdout.encoding, 'replace')
             versionInfo = versionInfo.encode(sys.stdout.encoding, 'replace')
         warning = notice + msg + versionInfo
-        print(warning)                          # __IGNORE_WARNING__
+        print(warning)                          # __IGNORE_WARNING_M801__
     else:
         warning = notice + msg + versionInfo
         # Escape &<> otherwise it's not visible in the error dialog
