@@ -425,7 +425,7 @@ def createPyWrapper(pydir, wfile, isGuiScript=True):
     return wname
 
 
-def copyTree(src, dst, filters, excludeDirs=[], excludePatterns=[]):
+def copyTree(src, dst, filters, excludeDirs=None, excludePatterns=None):
     """
     Copy Python, translation, documentation, wizards configuration,
     designer template files and DTDs of a directory tree.
@@ -437,6 +437,10 @@ def copyTree(src, dst, filters, excludeDirs=[], excludePatterns=[]):
     @keyparam excludePatterns list of filter pattern determining the files to
         be skipped
     """
+    if excludeDirs is None:
+        excludeDirs = []
+    if excludePatterns is None:
+        excludePatterns = []
     try:
         names = os.listdir(src)
     except OSError:
@@ -452,8 +456,8 @@ def copyTree(src, dst, filters, excludeDirs=[], excludePatterns=[]):
         if not skipIt:
             srcname = os.path.join(src, name)
             dstname = os.path.join(dst, name)
-            for filter in filters:
-                if fnmatch.fnmatch(srcname, filter):
+            for fileFilter in filters:
+                if fnmatch.fnmatch(srcname, fileFilter):
                     if not os.path.isdir(dst):
                         os.makedirs(dst)
                     shutil.copy2(srcname, dstname)
@@ -1089,15 +1093,19 @@ def createConfig():
         """    '''\n"""
         """    Module function to get a configuration value.\n"""
         """\n"""
-        """    @param name name of the configuration value (string)\n"""
+        """    @param name name of the configuration value"""
+        """    @type str\n"""
+        """    @exception AttributeError raised to indicate an invalid"""
+        """ config entry\n"""
         """    '''\n"""
         """    try:\n"""
         """        return _pkg_config[name]\n"""
         """    except KeyError:\n"""
         """        pass\n"""
         """\n"""
-        """    raise AttributeError('"{{0}}" is not a valid configuration"""
-        """ value'.format(name))\n"""
+        """    raise AttributeError(\n"""
+        """        '"{{0}}" is not a valid configuration value'"""
+        """.format(name))\n"""
     ).format(
         cfg['ericDir'], cfg['ericPixDir'], cfg['ericIconDir'],
         cfg['ericDTDDir'], cfg['ericCSSDir'],
@@ -1106,7 +1114,7 @@ def createConfig():
         cfg['ericTemplatesDir'],
         cfg['ericCodeTemplatesDir'], cfg['ericOthersDir'],
         cfg['bindir'], cfg['mdir'],
-        cfg['apidir'], apis,
+        cfg['apidir'], sorted(apis),
         macAppBundlePath, macAppBundleName,
     )
     copyToFile(fn, config)
@@ -1120,12 +1128,12 @@ def doDependancyChecks():
     
     # perform dependency checks
     print("Python Version: {0:d}.{1:d}.{2:d}".format(*sys.version_info[:3]))
-    if sys.version_info < (2, 7, 0):
-        print('Sorry, you must have Python 2.7.0 or higher or '
-              'Python 3.3.0 or higher.')
+    if sys.version_info < (2, 7, 10):
+        print('Sorry, you must have Python 2.7.10 or higher or '
+              'Python 3.4.0 or higher.')
         exit(5)
-    elif sys.version_info < (3, 3, 0) and sys.version_info[0] == 3:
-        print('Sorry, you must have Python 3.3.0 or higher.')
+    elif sys.version_info < (3, 4, 0) and sys.version_info[0] == 3:
+        print('Sorry, you must have Python 3.4.0 or higher.')
         exit(5)
     if sys.version_info > (3, 9, 9):
         print('Sorry, eric6 requires Python 3 or Python 2 for running.')
@@ -1231,12 +1239,12 @@ def doDependancyChecks():
         if "snapshot" not in sipVersion and "dev" not in sipVersion:
             while sipVersion.count('.') < 2:
                 sipVersion += '.0'
-            (maj, min, pat) = sipVersion.split('.')
-            maj = int(maj)
-            min = int(min)
+            (major, minor, pat) = sipVersion.split('.')
+            major = int(major)
+            minor = int(minor)
             pat = int(pat)
-            if maj < 4 or (maj == 4 and min < 14) or \
-                    (maj == 4 and min == 14 and pat < 2):
+            if major < 4 or (major == 4 and minor < 14) or \
+                    (major == 4 and minor == 14 and pat < 2):
                 print('Sorry, you must have sip 4.14.2 or higher or'
                       ' a recent snapshot release.')
                 exit(3)
@@ -1262,13 +1270,13 @@ def doDependancyChecks():
     if "snapshot" not in pyqtVersion and "dev" not in pyqtVersion:
         while pyqtVersion.count('.') < 2:
             pyqtVersion += '.0'
-        (maj, min, pat) = pyqtVersion.split('.')
-        maj = int(maj)
-        min = int(min)
+        (major, minor, pat) = pyqtVersion.split('.')
+        major = int(major)
+        minor = int(minor)
         pat = int(pat)
-        if maj < 4 or \
-            (maj == 4 and min < 10) or \
-                (maj == 5 and min < 3):
+        if major < 4 or \
+            (major == 4 and minor < 10) or \
+                (major == 5 and minor < 3):
             print('Sorry, you must have PyQt 4.10.0 or better or')
             print('PyQt 5.3.0 or better or'
                   ' a recent snapshot release.')
@@ -1292,11 +1300,11 @@ def doDependancyChecks():
     if "snapshot" not in scintillaVersion and "dev" not in scintillaVersion:
         while scintillaVersion.count('.') < 2:
             scintillaVersion += '.0'
-        (maj, min, pat) = scintillaVersion.split('.')
-        maj = int(maj)
-        min = int(min)
+        (major, minor, pat) = scintillaVersion.split('.')
+        major = int(major)
+        minor = int(minor)
         pat = int(pat)
-        if maj < 2 or (maj == 2 and min < 8):
+        if major < 2 or (major == 2 and minor < 8):
             print('Sorry, you must have QScintilla 2.8.0 or higher or'
                   ' a recent snapshot release.')
             exit(5)
